@@ -7,14 +7,15 @@ module Or_duplicate = struct
     | `Duplicate
     ]
   [@@deriving_inline sexp_of]
+
   let sexp_of_t :
-    'a . ('a -> Ppx_sexp_conv_lib.Sexp.t) -> 'a t -> Ppx_sexp_conv_lib.Sexp.t =
-    fun _of_a ->
-    function
-    | `Ok v0 ->
-      Ppx_sexp_conv_lib.Sexp.List
-        [Ppx_sexp_conv_lib.Sexp.Atom "Ok"; _of_a v0]
-    | `Duplicate -> Ppx_sexp_conv_lib.Sexp.Atom "Duplicate"
+    'a. ('a -> Ppx_sexp_conv_lib.Sexp.t) -> 'a t -> Ppx_sexp_conv_lib.Sexp.t
+    =
+    fun _of_a -> function
+      | `Ok v0 -> Ppx_sexp_conv_lib.Sexp.List [ Ppx_sexp_conv_lib.Sexp.Atom "Ok"; _of_a v0 ]
+      | `Duplicate -> Ppx_sexp_conv_lib.Sexp.Atom "Duplicate"
+  ;;
+
   [@@@end]
 end
 
@@ -34,45 +35,38 @@ end
 module Symmetric_diff_element = struct
   type ('k, 'v) t = 'k * [ `Left of 'v | `Right of 'v | `Unequal of 'v * 'v ]
   [@@deriving_inline compare, sexp]
+
   let compare :
-    'k 'v .
-    ('k -> 'k -> int) -> ('v -> 'v -> int) -> ('k, 'v) t -> ('k, 'v) t -> int
+    'k 'v. ('k -> 'k -> int) -> ('v -> 'v -> int) -> ('k, 'v) t -> ('k, 'v) t -> int
     =
-    fun _cmp__k ->
-    fun _cmp__v ->
-    fun a__001_ ->
-    fun b__002_ ->
-    let (t__003_, t__004_) = a__001_ in
-    let (t__005_, t__006_) = b__002_ in
+    fun _cmp__k _cmp__v a__001_ b__002_ ->
+    let t__003_, t__004_ = a__001_ in
+    let t__005_, t__006_ = b__002_ in
     match _cmp__k t__003_ t__005_ with
     | 0 ->
       if Ppx_compare_lib.phys_equal t__004_ t__006_
       then 0
-      else
-        (match (t__004_, t__006_) with
-         | (`Left _left__007_, `Left _right__008_) ->
-           _cmp__v _left__007_ _right__008_
-         | (`Right _left__009_, `Right _right__010_) ->
-           _cmp__v _left__009_ _right__010_
-         | (`Unequal _left__011_, `Unequal _right__012_) ->
-           let (t__013_, t__014_) = _left__011_ in
-           let (t__015_, t__016_) = _right__012_ in
-           (match _cmp__v t__013_ t__015_ with
-            | 0 -> _cmp__v t__014_ t__016_
-            | n -> n)
-         | (x, y) -> Ppx_compare_lib.polymorphic_compare x y)
+      else (
+        match t__004_, t__006_ with
+        | `Left _left__007_, `Left _right__008_ -> _cmp__v _left__007_ _right__008_
+        | `Right _left__009_, `Right _right__010_ -> _cmp__v _left__009_ _right__010_
+        | `Unequal _left__011_, `Unequal _right__012_ ->
+          let t__013_, t__014_ = _left__011_ in
+          let t__015_, t__016_ = _right__012_ in
+          (match _cmp__v t__013_ t__015_ with
+           | 0 -> _cmp__v t__014_ t__016_
+           | n -> n)
+        | x, y -> Ppx_compare_lib.polymorphic_compare x y)
     | n -> n
+  ;;
+
   let t_of_sexp :
-    'k 'v .
-    (Ppx_sexp_conv_lib.Sexp.t -> 'k) ->
-    (Ppx_sexp_conv_lib.Sexp.t -> 'v) ->
-    Ppx_sexp_conv_lib.Sexp.t -> ('k, 'v) t
+    'k 'v. (Ppx_sexp_conv_lib.Sexp.t -> 'k) -> (Ppx_sexp_conv_lib.Sexp.t -> 'v)
+    -> Ppx_sexp_conv_lib.Sexp.t -> ('k, 'v) t
     =
-    let _tp_loc = "src/map_intf.ml.Symmetric_diff_element.t" in
-    fun _of_k ->
-    fun _of_v ->
-      function
-      | Ppx_sexp_conv_lib.Sexp.List (v0::v1::[]) ->
+    let _tp_loc = "map_intf.ml.Symmetric_diff_element.t" in
+    fun _of_k _of_v -> function
+      | Ppx_sexp_conv_lib.Sexp.List [ v0; v1 ] ->
         let v0 = _of_k v0
         and v1 =
           (fun sexp ->
@@ -80,89 +74,84 @@ module Symmetric_diff_element = struct
                match sexp with
                | Ppx_sexp_conv_lib.Sexp.Atom atom as _sexp ->
                  (match atom with
-                  | "Left" ->
-                    Ppx_sexp_conv_lib.Conv_error.ptag_takes_args
-                      _tp_loc _sexp
-                  | "Right" ->
-                    Ppx_sexp_conv_lib.Conv_error.ptag_takes_args
-                      _tp_loc _sexp
-                  | "Unequal" ->
-                    Ppx_sexp_conv_lib.Conv_error.ptag_takes_args
-                      _tp_loc _sexp
+                  | "Left" -> Ppx_sexp_conv_lib.Conv_error.ptag_takes_args _tp_loc _sexp
+                  | "Right" -> Ppx_sexp_conv_lib.Conv_error.ptag_takes_args _tp_loc _sexp
+                  | "Unequal" -> Ppx_sexp_conv_lib.Conv_error.ptag_takes_args _tp_loc _sexp
                   | _ -> Ppx_sexp_conv_lib.Conv_error.no_variant_match ())
-               | Ppx_sexp_conv_lib.Sexp.List ((Ppx_sexp_conv_lib.Sexp.Atom
-                                                 atom)::sexp_args) as _sexp ->
+               | Ppx_sexp_conv_lib.Sexp.List
+                   (Ppx_sexp_conv_lib.Sexp.Atom atom :: sexp_args) as _sexp ->
                  (match atom with
                   | "Left" as _tag ->
                     (match sexp_args with
-                     | v0::[] -> let v0 = _of_v v0 in `Left v0
+                     | [ v0 ] ->
+                       let v0 = _of_v v0 in
+                       `Left v0
                      | _ ->
-                       Ppx_sexp_conv_lib.Conv_error.ptag_incorrect_n_args
-                         _tp_loc _tag _sexp)
+                       Ppx_sexp_conv_lib.Conv_error.ptag_incorrect_n_args _tp_loc _tag _sexp)
                   | "Right" as _tag ->
                     (match sexp_args with
-                     | v0::[] -> let v0 = _of_v v0 in `Right v0
+                     | [ v0 ] ->
+                       let v0 = _of_v v0 in
+                       `Right v0
                      | _ ->
-                       Ppx_sexp_conv_lib.Conv_error.ptag_incorrect_n_args
-                         _tp_loc _tag _sexp)
+                       Ppx_sexp_conv_lib.Conv_error.ptag_incorrect_n_args _tp_loc _tag _sexp)
                   | "Unequal" as _tag ->
                     (match sexp_args with
-                     | v0::[] ->
+                     | [ v0 ] ->
                        let v0 =
                          match v0 with
-                         | Ppx_sexp_conv_lib.Sexp.List (v0::v1::[])
-                           ->
+                         | Ppx_sexp_conv_lib.Sexp.List [ v0; v1 ] ->
                            let v0 = _of_v v0
-                           and v1 = _of_v v1 in (v0, v1)
+                           and v1 = _of_v v1 in
+                           v0, v1
                          | sexp ->
                            Ppx_sexp_conv_lib.Conv_error.tuple_of_size_n_expected
-                             _tp_loc 2 sexp in
+                             _tp_loc
+                             2
+                             sexp
+                       in
                        `Unequal v0
                      | _ ->
-                       Ppx_sexp_conv_lib.Conv_error.ptag_incorrect_n_args
-                         _tp_loc _tag _sexp)
+                       Ppx_sexp_conv_lib.Conv_error.ptag_incorrect_n_args _tp_loc _tag _sexp)
                   | _ -> Ppx_sexp_conv_lib.Conv_error.no_variant_match ())
-               | Ppx_sexp_conv_lib.Sexp.List ((Ppx_sexp_conv_lib.Sexp.List
-                                                 _)::_) as sexp ->
-                 Ppx_sexp_conv_lib.Conv_error.nested_list_invalid_poly_var
-                   _tp_loc sexp
+               | Ppx_sexp_conv_lib.Sexp.List (Ppx_sexp_conv_lib.Sexp.List _ :: _) as sexp
+                 -> Ppx_sexp_conv_lib.Conv_error.nested_list_invalid_poly_var _tp_loc sexp
                | Ppx_sexp_conv_lib.Sexp.List [] as sexp ->
-                 Ppx_sexp_conv_lib.Conv_error.empty_list_invalid_poly_var
-                   _tp_loc sexp
+                 Ppx_sexp_conv_lib.Conv_error.empty_list_invalid_poly_var _tp_loc sexp
              with
              | Ppx_sexp_conv_lib.Conv_error.No_variant_match ->
-               Ppx_sexp_conv_lib.Conv_error.no_matching_variant_found
-                 _tp_loc sexp) v1 in
-        (v0, v1)
-      | sexp ->
-        Ppx_sexp_conv_lib.Conv_error.tuple_of_size_n_expected _tp_loc 2
-          sexp
+               Ppx_sexp_conv_lib.Conv_error.no_matching_variant_found _tp_loc sexp)
+            v1
+        in
+        v0, v1
+      | sexp -> Ppx_sexp_conv_lib.Conv_error.tuple_of_size_n_expected _tp_loc 2 sexp
+  ;;
+
   let sexp_of_t :
-    'k 'v .
-    ('k -> Ppx_sexp_conv_lib.Sexp.t) ->
-    ('v -> Ppx_sexp_conv_lib.Sexp.t) ->
-    ('k, 'v) t -> Ppx_sexp_conv_lib.Sexp.t
+    'k 'v. ('k -> Ppx_sexp_conv_lib.Sexp.t) -> ('v -> Ppx_sexp_conv_lib.Sexp.t)
+    -> ('k, 'v) t -> Ppx_sexp_conv_lib.Sexp.t
     =
-    fun _of_k ->
-    fun _of_v ->
-    function
-    | (v0, v1) ->
-      let v0 = _of_k v0
-      and v1 =
-        match v1 with
-        | `Left v0 ->
-          Ppx_sexp_conv_lib.Sexp.List
-            [Ppx_sexp_conv_lib.Sexp.Atom "Left"; _of_v v0]
-        | `Right v0 ->
-          Ppx_sexp_conv_lib.Sexp.List
-            [Ppx_sexp_conv_lib.Sexp.Atom "Right"; _of_v v0]
-        | `Unequal v0 ->
-          Ppx_sexp_conv_lib.Sexp.List
-            [Ppx_sexp_conv_lib.Sexp.Atom "Unequal";
-             (let (v0, v1) = v0 in
-              let v0 = _of_v v0
-              and v1 = _of_v v1 in Ppx_sexp_conv_lib.Sexp.List [v0; v1])] in
-      Ppx_sexp_conv_lib.Sexp.List [v0; v1]
+    fun _of_k _of_v -> function
+      | v0, v1 ->
+        let v0 = _of_k v0
+        and v1 =
+          match v1 with
+          | `Left v0 ->
+            Ppx_sexp_conv_lib.Sexp.List [ Ppx_sexp_conv_lib.Sexp.Atom "Left"; _of_v v0 ]
+          | `Right v0 ->
+            Ppx_sexp_conv_lib.Sexp.List [ Ppx_sexp_conv_lib.Sexp.Atom "Right"; _of_v v0 ]
+          | `Unequal v0 ->
+            Ppx_sexp_conv_lib.Sexp.List
+              [ Ppx_sexp_conv_lib.Sexp.Atom "Unequal"
+              ; (let v0, v1 = v0 in
+                 let v0 = _of_v v0
+                 and v1 = _of_v v1 in
+                 Ppx_sexp_conv_lib.Sexp.List [ v0; v1 ])
+              ]
+        in
+        Ppx_sexp_conv_lib.Sexp.List [ v0; v1 ]
+  ;;
+
   [@@@end]
 end
 
@@ -171,14 +160,18 @@ module Continue_or_stop = struct
     | Continue
     | Stop
   [@@deriving_inline compare, enumerate, equal, sexp_of]
+
   let compare = (Ppx_compare_lib.polymorphic_compare : t -> t -> int)
-  let all = ([Continue; Stop] : t list)
+  let all = ([ Continue; Stop ] : t list)
   let equal = (Ppx_compare_lib.polymorphic_equal : t -> t -> bool)
+
   let sexp_of_t =
     (function
       | Continue -> Ppx_sexp_conv_lib.Sexp.Atom "Continue"
-      | Stop -> Ppx_sexp_conv_lib.Sexp.Atom "Stop" : t ->
-        Ppx_sexp_conv_lib.Sexp.t)
+      | Stop -> Ppx_sexp_conv_lib.Sexp.Atom "Stop"
+                : t -> Ppx_sexp_conv_lib.Sexp.t)
+  ;;
+
   [@@@end]
 end
 
@@ -187,14 +180,18 @@ module Finished_or_unfinished = struct
     | Finished
     | Unfinished
   [@@deriving_inline compare, enumerate, equal, sexp_of]
+
   let compare = (Ppx_compare_lib.polymorphic_compare : t -> t -> int)
-  let all = ([Finished; Unfinished] : t list)
+  let all = ([ Finished; Unfinished ] : t list)
   let equal = (Ppx_compare_lib.polymorphic_equal : t -> t -> bool)
+
   let sexp_of_t =
     (function
       | Finished -> Ppx_sexp_conv_lib.Sexp.Atom "Finished"
-      | Unfinished -> Ppx_sexp_conv_lib.Sexp.Atom "Unfinished" : t ->
-        Ppx_sexp_conv_lib.Sexp.t)
+      | Unfinished -> Ppx_sexp_conv_lib.Sexp.Atom "Unfinished"
+                      : t -> Ppx_sexp_conv_lib.Sexp.t)
+  ;;
+
   [@@@end]
 end
 
@@ -317,7 +314,7 @@ module type Accessors_generic = sig
     : ( 'k
       , 'cmp
       , ('k, 'v1, 'cmp) t
-      -> f:(key:'k key -> data:'v1 -> [ `Fst of 'v2 | `Snd of 'v3 ])
+      -> f:(key:'k key -> data:'v1 -> ('v2, 'v3) Either.t)
       -> ('k, 'v2, 'cmp) t * ('k, 'v3, 'cmp) t )
         options
 
@@ -325,7 +322,7 @@ module type Accessors_generic = sig
     : ( 'k
       , 'cmp
       , ('k, 'v1, 'cmp) t
-      -> f:('v1 -> [ `Fst of 'v2 | `Snd of 'v3 ])
+      -> f:('v1 -> ('v2, 'v3) Either.t)
       -> ('k, 'v2, 'cmp) t * ('k, 'v3, 'cmp) t )
         options
 
@@ -343,6 +340,9 @@ module type Accessors_generic = sig
       , ('k, 'v, 'cmp) t -> f:('v -> bool) -> ('k, 'v, 'cmp) t * ('k, 'v, 'cmp) t )
         options
 
+  val combine_errors
+    : ('k, 'cmp, ('k, 'v Or_error.t, 'cmp) t -> ('k, 'v, 'cmp) t Or_error.t) options
+
   val compare_direct
     : ( 'k
       , 'cmp
@@ -368,6 +368,11 @@ module type Accessors_generic = sig
     -> 'v Validate.check
     -> ('k, 'v, _) t Validate.check
 
+  val validatei
+    :  name:('k key -> string)
+    -> ('k key * 'v) Validate.check
+    -> ('k, 'v, _) t Validate.check
+
   val merge
     : ( 'k
       , 'cmp
@@ -555,15 +560,11 @@ module type Accessors1 = sig
   val filteri : 'a t -> f:(key:key -> data:'a -> bool) -> 'a t
   val filter_map : 'a t -> f:('a -> 'b option) -> 'b t
   val filter_mapi : 'a t -> f:(key:key -> data:'a -> 'b option) -> 'b t
-
-  val partition_mapi
-    :  'a t
-    -> f:(key:key -> data:'a -> [ `Fst of 'b | `Snd of 'c ])
-    -> 'b t * 'c t
-
-  val partition_map : 'a t -> f:('a -> [ `Fst of 'b | `Snd of 'c ]) -> 'b t * 'c t
+  val partition_mapi : 'a t -> f:(key:key -> data:'a -> ('b, 'c) Either.t) -> 'b t * 'c t
+  val partition_map : 'a t -> f:('a -> ('b, 'c) Either.t) -> 'b t * 'c t
   val partitioni_tf : 'a t -> f:(key:key -> data:'a -> bool) -> 'a t * 'a t
   val partition_tf : 'a t -> f:('a -> bool) -> 'a t * 'a t
+  val combine_errors : 'a Or_error.t t -> 'a t Or_error.t
   val compare_direct : ('a -> 'a -> int) -> 'a t -> 'a t -> int
   val equal : ('a -> 'a -> bool) -> 'a t -> 'a t -> bool
   val keys : _ t -> key list
@@ -571,6 +572,11 @@ module type Accessors1 = sig
   val to_alist : ?key_order:[ `Increasing | `Decreasing ] -> 'a t -> (key * 'a) list
   val validate : name:(key -> string) -> 'a Validate.check -> 'a t Validate.check
 
+  val validatei
+    :  name:(key -> string)
+    -> (key * 'a) Validate.check
+    -> 'a t Validate.check
+
   val merge
     :  'a t
     -> 'b t
@@ -717,12 +723,12 @@ module type Accessors2 = sig
 
   val partition_mapi
     :  ('a, 'b) t
-    -> f:(key:'a -> data:'b -> [ `Fst of 'c | `Snd of 'd ])
+    -> f:(key:'a -> data:'b -> ('c, 'd) Either.t)
     -> ('a, 'c) t * ('a, 'd) t
 
   val partition_map
     :  ('a, 'b) t
-    -> f:('b -> [ `Fst of 'c | `Snd of 'd ])
+    -> f:('b -> ('c, 'd) Either.t)
     -> ('a, 'c) t * ('a, 'd) t
 
   val partitioni_tf
@@ -731,6 +737,7 @@ module type Accessors2 = sig
     -> ('a, 'b) t * ('a, 'b) t
 
   val partition_tf : ('a, 'b) t -> f:('b -> bool) -> ('a, 'b) t * ('a, 'b) t
+  val combine_errors : ('a, 'b Or_error.t) t -> ('a, 'b) t Or_error.t
   val compare_direct : ('b -> 'b -> int) -> ('a, 'b) t -> ('a, 'b) t -> int
   val equal : ('b -> 'b -> bool) -> ('a, 'b) t -> ('a, 'b) t -> bool
   val keys : ('a, _) t -> 'a list
@@ -738,6 +745,11 @@ module type Accessors2 = sig
   val to_alist : ?key_order:[ `Increasing | `Decreasing ] -> ('a, 'b) t -> ('a * 'b) list
   val validate : name:('a -> string) -> 'b Validate.check -> ('a, 'b) t Validate.check
 
+  val validatei
+    :  name:('a -> string)
+    -> ('a * 'b) Validate.check
+    -> ('a, 'b) t Validate.check
+
   val merge
     :  ('a, 'b) t
     -> ('a, 'c) t
@@ -887,12 +899,12 @@ module type Accessors3 = sig
 
   val partition_mapi
     :  ('a, 'b, 'cmp) t
-    -> f:(key:'a -> data:'b -> [ `Fst of 'c | `Snd of 'd ])
+    -> f:(key:'a -> data:'b -> ('c, 'd) Either.t)
     -> ('a, 'c, 'cmp) t * ('a, 'd, 'cmp) t
 
   val partition_map
     :  ('a, 'b, 'cmp) t
-    -> f:('b -> [ `Fst of 'c | `Snd of 'd ])
+    -> f:('b -> ('c, 'd) Either.t)
     -> ('a, 'c, 'cmp) t * ('a, 'd, 'cmp) t
 
   val partitioni_tf
@@ -905,6 +917,7 @@ module type Accessors3 = sig
     -> f:('b -> bool)
     -> ('a, 'b, 'cmp) t * ('a, 'b, 'cmp) t
 
+  val combine_errors : ('a, 'b Or_error.t, 'cmp) t -> ('a, 'b, 'cmp) t Or_error.t
   val compare_direct : ('b -> 'b -> int) -> ('a, 'b, 'cmp) t -> ('a, 'b, 'cmp) t -> int
   val equal : ('b -> 'b -> bool) -> ('a, 'b, 'cmp) t -> ('a, 'b, 'cmp) t -> bool
   val keys : ('a, _, _) t -> 'a list
@@ -917,6 +930,11 @@ module type Accessors3 = sig
 
   val validate : name:('a -> string) -> 'b Validate.check -> ('a, 'b, _) t Validate.check
 
+  val validatei
+    :  name:('a -> string)
+    -> ('a * 'b) Validate.check
+    -> ('a, 'b, _) t Validate.check
+
   val merge
     :  ('a, 'b, 'cmp) t
     -> ('a, 'c, 'cmp) t
@@ -1146,13 +1164,13 @@ module type Accessors3_with_comparator = sig
   val partition_mapi
     :  comparator:('a, 'cmp) Comparator.t
     -> ('a, 'b, 'cmp) t
-    -> f:(key:'a -> data:'b -> [ `Fst of 'c | `Snd of 'd ])
+    -> f:(key:'a -> data:'b -> ('c, 'd) Either.t)
     -> ('a, 'c, 'cmp) t * ('a, 'd, 'cmp) t
 
   val partition_map
     :  comparator:('a, 'cmp) Comparator.t
     -> ('a, 'b, 'cmp) t
-    -> f:('b -> [ `Fst of 'c | `Snd of 'd ])
+    -> f:('b -> ('c, 'd) Either.t)
     -> ('a, 'c, 'cmp) t * ('a, 'd, 'cmp) t
 
   val partitioni_tf
@@ -1167,6 +1185,11 @@ module type Accessors3_with_comparator = sig
     -> f:('b -> bool)
     -> ('a, 'b, 'cmp) t * ('a, 'b, 'cmp) t
 
+  val combine_errors
+    :  comparator:('a, 'cmp) Comparator.t
+    -> ('a, 'b Or_error.t, 'cmp) t
+    -> ('a, 'b, 'cmp) t Or_error.t
+
   val compare_direct
     :  comparator:('a, 'cmp) Comparator.t
     -> ('b -> 'b -> int)
@@ -1191,6 +1214,11 @@ module type Accessors3_with_comparator = sig
 
   val validate : name:('a -> string) -> 'b Validate.check -> ('a, 'b, _) t Validate.check
 
+  val validatei
+    :  name:('a -> string)
+    -> ('a * 'b) Validate.check
+    -> ('a, 'b, _) t Validate.check
+
   val merge
     :  comparator:('a, 'cmp) Comparator.t
     -> ('a, 'b, 'cmp) t
@@ -1761,17 +1789,17 @@ module type For_deriving = sig
 
   module type Sexp_of_m = sig
     type t [@@deriving_inline sexp_of]
-    include
-      sig [@@@ocaml.warning "-32"] val sexp_of_t : t -> Ppx_sexp_conv_lib.Sexp.t
-      end[@@ocaml.doc "@inline"]
+
+    val sexp_of_t : t -> Ppx_sexp_conv_lib.Sexp.t
+
     [@@@end]
   end
 
   module type M_of_sexp = sig
     type t [@@deriving_inline of_sexp]
-    include
-      sig [@@@ocaml.warning "-32"] val t_of_sexp : Ppx_sexp_conv_lib.Sexp.t -> t
-      end[@@ocaml.doc "@inline"]
+
+    val t_of_sexp : Ppx_sexp_conv_lib.Sexp.t -> t
+
     [@@@end]
 
     include Comparator.S with type t := t
@@ -1793,6 +1821,8 @@ module type For_deriving = sig
     -> Sexp.t
     -> ('k, 'v, 'cmp) t
 
+  val m__t_sexp_grammar : Ppx_sexp_conv_lib.Sexp.Private.Raw_grammar.t
+
   val compare_m__t
     :  (module Compare_m)
     -> ('v -> 'v -> int)
@@ -1829,14 +1859,12 @@ module type Map = sig
       | Finished
       | Unfinished
     [@@deriving_inline compare, enumerate, equal, sexp_of]
-    include
-      sig
-        [@@@ocaml.warning "-32"]
-        val compare : t -> t -> int
-        val all : t list
-        val equal : t -> t -> bool
-        val sexp_of_t : t -> Ppx_sexp_conv_lib.Sexp.t
-      end[@@ocaml.doc "@inline"]
+
+    val compare : t -> t -> int
+    val all : t list
+    val equal : t -> t -> bool
+    val sexp_of_t : t -> Ppx_sexp_conv_lib.Sexp.t
+
     [@@@end]
 
     (** Maps [Continue] to [Finished] and [Stop] to [Unfinished]. *)
@@ -2126,18 +2154,17 @@ module type Map = sig
     -> f:(key:'k -> data:'v1 -> 'v2 option)
     -> ('k, 'v2, 'cmp) t
 
-
   (** [partition_mapi t ~f] returns two new [t]s, with each key in [t] appearing in
       exactly one of the resulting maps depending on its mapping in [f]. *)
   val partition_mapi
     :  ('k, 'v1, 'cmp) t
-    -> f:(key:'k -> data:'v1 -> [ `Fst of 'v2 | `Snd of 'v3 ])
+    -> f:(key:'k -> data:'v1 -> ('v2, 'v3) Either.t)
     -> ('k, 'v2, 'cmp) t * ('k, 'v3, 'cmp) t
 
   (** [partition_map t ~f = partition_mapi t ~f:(fun ~key:_ ~data -> f data)] *)
   val partition_map
     :  ('k, 'v1, 'cmp) t
-    -> f:('v1 -> [ `Fst of 'v2 | `Snd of 'v3 ])
+    -> f:('v1 -> ('v2, 'v3) Either.t)
     -> ('k, 'v2, 'cmp) t * ('k, 'v3, 'cmp) t
 
   (**
@@ -2146,8 +2173,8 @@ module type Map = sig
        =
        partition_mapi t ~f:(fun ~key ~data ->
          if f ~key ~data
-         then `Fst data
-         else `Snd data)
+         then First data
+         else Second data)
      ]} *)
   val partitioni_tf
     :  ('k, 'v, 'cmp) t
@@ -2160,6 +2187,10 @@ module type Map = sig
     -> f:('v -> bool)
     -> ('k, 'v, 'cmp) t * ('k, 'v, 'cmp) t
 
+  (** Produces [Ok] of a map including all keys if all data is [Ok], or an [Error]
+      including all errors otherwise. *)
+  val combine_errors : ('k, 'v Or_error.t, 'cmp) t -> ('k, 'v, 'cmp) t Or_error.t
+
   (** Returns a total ordering between maps. The first argument is a total ordering used
       to compare data associated with equal keys in the two maps. *)
   val compare_direct : ('v -> 'v -> int) -> ('k, 'v, 'cmp) t -> ('k, 'v, 'cmp) t -> int
@@ -2189,6 +2220,11 @@ module type Map = sig
 
   val validate : name:('k -> string) -> 'v Validate.check -> ('k, 'v, _) t Validate.check
 
+  val validatei
+    :  name:('k -> string)
+    -> ('k * 'v) Validate.check
+    -> ('k, 'v, _) t Validate.check
+
   (** {2 Additional operations on maps} *)
 
   (** Merges two maps. The runtime is O(length(t1) + length(t2)). You shouldn't use this
@@ -2217,14 +2253,16 @@ module type Map = sig
   module Symmetric_diff_element : sig
     type ('k, 'v) t = 'k * [ `Left of 'v | `Right of 'v | `Unequal of 'v * 'v ]
     [@@deriving_inline compare, sexp]
-    include
-      sig
-        [@@@ocaml.warning "-32"]
-        val compare :
-          ('k -> 'k -> int) ->
-          ('v -> 'v -> int) -> ('k, 'v) t -> ('k, 'v) t -> int
-        include Ppx_sexp_conv_lib.Sexpable.S2 with type ('k,'v) t :=  ('k, 'v) t
-      end[@@ocaml.doc "@inline"]
+
+    val compare
+      :  ('k -> 'k -> int)
+      -> ('v -> 'v -> int)
+      -> ('k, 'v) t
+      -> ('k, 'v) t
+      -> int
+
+    include Ppx_sexp_conv_lib.Sexpable.S2 with type ('k, 'v) t := ('k, 'v) t
+
     [@@@end]
   end
 
@@ -2278,6 +2316,7 @@ module type Map = sig
   val count : ('k, 'v, _) t -> f:('v -> bool) -> int
   val counti : ('k, 'v, _) t -> f:(key:'k -> data:'v -> bool) -> int
 
+
   (** [split t key] returns a map of keys strictly less than [key], the mapping of [key] if
       any, and a map of keys strictly greater than [key].
 
@@ -2363,11 +2402,19 @@ module type Map = sig
       [t], and [None] otherwise. *)
   val rank : ('k, 'v, 'cmp) t -> 'k -> int option
 
-  (** [to_sequence ?order ?keys_greater_or_equal_to ?keys_less_or_equal_to t] gives a
-      sequence of key-value pairs between [keys_less_or_equal_to] and
+
+
+  (** [to_sequence ?order ?keys_greater_or_equal_to ?keys_less_or_equal_to t]
+      gives a sequence of key-value pairs between [keys_less_or_equal_to] and
       [keys_greater_or_equal_to] inclusive, presented in [order].  If
-      [keys_greater_or_equal_to > keys_less_or_equal_to], the sequence is empty.  Cost is
-      O(log n) up front and amortized O(1) to produce each element. *)
+      [keys_greater_or_equal_to > keys_less_or_equal_to], the sequence is
+      empty.
+
+      When neither [keys_greater_or_equal_to] nor [keys_less_or_equal_to] are
+      provided, the cost is O(log n) up front and amortized O(1) to produce
+      each element. If either is provided (and is used by the order parameter
+      provided), then the the cost is O(n) up front, and amortized O(1) to
+      produce each element. *)
   val to_sequence
     :  ?order:[ `Increasing_key (** default *) | `Decreasing_key ]
     -> ?keys_greater_or_equal_to:'k
@@ -2441,12 +2488,12 @@ module type Map = sig
       doesn't (because there is no such thing as, say, [String.sexp_of_comparator_witness]
       -- instead you would want to pass the comparator directly).
 
-      In addition, when using [@@deriving_inline][@@@end], the requirements on the key module are only
+      In addition, when using [@@deriving], the requirements on the key module are only
       those needed to satisfy what you are trying to derive on the map itself. Say you
       write:
 
       {[
-        type t = int Map.M(X).t [@@deriving_inline hash][@@@end]
+        type t = int Map.M(X).t [@@deriving hash]
       ]}
 
       then this will be well typed exactly if [X] contains at least:
@@ -2472,15 +2519,14 @@ module type Map = sig
       toplevel of [Map] take a [('k, 'cmp) comparator]. *)
   module Using_comparator : sig
     type nonrec ('k, +'v, 'cmp) t = ('k, 'v, 'cmp) t [@@deriving_inline sexp_of]
-    include
-      sig
-        [@@@ocaml.warning "-32"]
-        val sexp_of_t :
-          ('k -> Ppx_sexp_conv_lib.Sexp.t) ->
-          ('v -> Ppx_sexp_conv_lib.Sexp.t) ->
-          ('cmp -> Ppx_sexp_conv_lib.Sexp.t) ->
-          ('k, 'v, 'cmp) t -> Ppx_sexp_conv_lib.Sexp.t
-      end[@@ocaml.doc "@inline"]
+
+    val sexp_of_t
+      :  ('k -> Ppx_sexp_conv_lib.Sexp.t)
+      -> ('v -> Ppx_sexp_conv_lib.Sexp.t)
+      -> ('cmp -> Ppx_sexp_conv_lib.Sexp.t)
+      -> ('k, 'v, 'cmp) t
+      -> Ppx_sexp_conv_lib.Sexp.t
+
     [@@@end]
 
     val t_of_sexp_direct
@@ -2492,15 +2538,14 @@ module type Map = sig
 
     module Tree : sig
       type ('k, +'v, 'cmp) t [@@deriving_inline sexp_of]
-      include
-        sig
-          [@@@ocaml.warning "-32"]
-          val sexp_of_t :
-            ('k -> Ppx_sexp_conv_lib.Sexp.t) ->
-            ('v -> Ppx_sexp_conv_lib.Sexp.t) ->
-            ('cmp -> Ppx_sexp_conv_lib.Sexp.t) ->
-            ('k, 'v, 'cmp) t -> Ppx_sexp_conv_lib.Sexp.t
-        end[@@ocaml.doc "@inline"]
+
+      val sexp_of_t
+        :  ('k -> Ppx_sexp_conv_lib.Sexp.t)
+        -> ('v -> Ppx_sexp_conv_lib.Sexp.t)
+        -> ('cmp -> Ppx_sexp_conv_lib.Sexp.t)
+        -> ('k, 'v, 'cmp) t
+        -> Ppx_sexp_conv_lib.Sexp.t
+
       [@@@end]
 
       val t_of_sexp_direct
