@@ -7,56 +7,62 @@ module T = struct
     | Pos
     | Nan
   [@@deriving_inline sexp, compare, hash, enumerate]
+
   let t_of_sexp =
-    (let _tp_loc = "src/sign_or_nan.ml.T.t" in
+    (let _tp_loc = "sign_or_nan.ml.T.t" in
      function
-     | Ppx_sexp_conv_lib.Sexp.Atom ("neg"|"Neg") -> Neg
-     | Ppx_sexp_conv_lib.Sexp.Atom ("zero"|"Zero") -> Zero
-     | Ppx_sexp_conv_lib.Sexp.Atom ("pos"|"Pos") -> Pos
-     | Ppx_sexp_conv_lib.Sexp.Atom ("nan"|"Nan") -> Nan
-     | Ppx_sexp_conv_lib.Sexp.List ((Ppx_sexp_conv_lib.Sexp.Atom
-                                       ("neg"|"Neg"))::_) as sexp ->
-       Ppx_sexp_conv_lib.Conv_error.stag_no_args _tp_loc sexp
-     | Ppx_sexp_conv_lib.Sexp.List ((Ppx_sexp_conv_lib.Sexp.Atom
-                                       ("zero"|"Zero"))::_) as sexp ->
-       Ppx_sexp_conv_lib.Conv_error.stag_no_args _tp_loc sexp
-     | Ppx_sexp_conv_lib.Sexp.List ((Ppx_sexp_conv_lib.Sexp.Atom
-                                       ("pos"|"Pos"))::_) as sexp ->
-       Ppx_sexp_conv_lib.Conv_error.stag_no_args _tp_loc sexp
-     | Ppx_sexp_conv_lib.Sexp.List ((Ppx_sexp_conv_lib.Sexp.Atom
-                                       ("nan"|"Nan"))::_) as sexp ->
-       Ppx_sexp_conv_lib.Conv_error.stag_no_args _tp_loc sexp
-     | Ppx_sexp_conv_lib.Sexp.List ((Ppx_sexp_conv_lib.Sexp.List _)::_) as sexp
-       -> Ppx_sexp_conv_lib.Conv_error.nested_list_invalid_sum _tp_loc sexp
+     | Ppx_sexp_conv_lib.Sexp.Atom ("neg" | "Neg") -> Neg
+     | Ppx_sexp_conv_lib.Sexp.Atom ("zero" | "Zero") -> Zero
+     | Ppx_sexp_conv_lib.Sexp.Atom ("pos" | "Pos") -> Pos
+     | Ppx_sexp_conv_lib.Sexp.Atom ("nan" | "Nan") -> Nan
+     | Ppx_sexp_conv_lib.Sexp.List (Ppx_sexp_conv_lib.Sexp.Atom ("neg" | "Neg") :: _) as
+       sexp -> Ppx_sexp_conv_lib.Conv_error.stag_no_args _tp_loc sexp
+     | Ppx_sexp_conv_lib.Sexp.List (Ppx_sexp_conv_lib.Sexp.Atom ("zero" | "Zero") :: _)
+       as sexp -> Ppx_sexp_conv_lib.Conv_error.stag_no_args _tp_loc sexp
+     | Ppx_sexp_conv_lib.Sexp.List (Ppx_sexp_conv_lib.Sexp.Atom ("pos" | "Pos") :: _) as
+       sexp -> Ppx_sexp_conv_lib.Conv_error.stag_no_args _tp_loc sexp
+     | Ppx_sexp_conv_lib.Sexp.List (Ppx_sexp_conv_lib.Sexp.Atom ("nan" | "Nan") :: _) as
+       sexp -> Ppx_sexp_conv_lib.Conv_error.stag_no_args _tp_loc sexp
+     | Ppx_sexp_conv_lib.Sexp.List (Ppx_sexp_conv_lib.Sexp.List _ :: _) as sexp ->
+       Ppx_sexp_conv_lib.Conv_error.nested_list_invalid_sum _tp_loc sexp
      | Ppx_sexp_conv_lib.Sexp.List [] as sexp ->
        Ppx_sexp_conv_lib.Conv_error.empty_list_invalid_sum _tp_loc sexp
-     | sexp -> Ppx_sexp_conv_lib.Conv_error.unexpected_stag _tp_loc sexp :
-                 Ppx_sexp_conv_lib.Sexp.t -> t)
+     | sexp -> Ppx_sexp_conv_lib.Conv_error.unexpected_stag _tp_loc sexp
+               : Ppx_sexp_conv_lib.Sexp.t -> t)
+  ;;
+
   let sexp_of_t =
     (function
       | Neg -> Ppx_sexp_conv_lib.Sexp.Atom "Neg"
       | Zero -> Ppx_sexp_conv_lib.Sexp.Atom "Zero"
       | Pos -> Ppx_sexp_conv_lib.Sexp.Atom "Pos"
-      | Nan -> Ppx_sexp_conv_lib.Sexp.Atom "Nan" : t -> Ppx_sexp_conv_lib.Sexp.t)
+      | Nan -> Ppx_sexp_conv_lib.Sexp.Atom "Nan"
+               : t -> Ppx_sexp_conv_lib.Sexp.t)
+  ;;
+
   let compare = (Ppx_compare_lib.polymorphic_compare : t -> t -> int)
-  let (hash_fold_t :
-         Ppx_hash_lib.Std.Hash.state -> t -> Ppx_hash_lib.Std.Hash.state) =
-    (fun hsv ->
-       fun arg ->
-         match arg with
-         | Neg -> Ppx_hash_lib.Std.Hash.fold_int hsv 0
-         | Zero -> Ppx_hash_lib.Std.Hash.fold_int hsv 1
-         | Pos -> Ppx_hash_lib.Std.Hash.fold_int hsv 2
-         | Nan -> Ppx_hash_lib.Std.Hash.fold_int hsv 3 : Ppx_hash_lib.Std.Hash.state
-         ->
-           t ->
-         Ppx_hash_lib.Std.Hash.state)
+
+  let (hash_fold_t : Ppx_hash_lib.Std.Hash.state -> t -> Ppx_hash_lib.Std.Hash.state) =
+    (fun hsv arg ->
+       match arg with
+       | Neg -> Ppx_hash_lib.Std.Hash.fold_int hsv 0
+       | Zero -> Ppx_hash_lib.Std.Hash.fold_int hsv 1
+       | Pos -> Ppx_hash_lib.Std.Hash.fold_int hsv 2
+       | Nan -> Ppx_hash_lib.Std.Hash.fold_int hsv 3
+                : Ppx_hash_lib.Std.Hash.state -> t -> Ppx_hash_lib.Std.Hash.state)
+  ;;
+
   let (hash : t -> Ppx_hash_lib.Std.Hash.hash_value) =
     let func arg =
       Ppx_hash_lib.Std.Hash.get_hash_value
-        (let hsv = Ppx_hash_lib.Std.Hash.create () in hash_fold_t hsv arg) in
+        (let hsv = Ppx_hash_lib.Std.Hash.create () in
+         hash_fold_t hsv arg)
+    in
     fun x -> func x
-  let all = ([Neg; Zero; Pos; Nan] : t list)
+  ;;
+
+  let all = ([ Neg; Zero; Pos; Nan ] : t list)
+
   [@@@end]
 
   let of_string s = t_of_sexp (sexp_of_string s)
